<?php
/**
 * VTBPay Module Integration
 *
 * This script defines a hook function for integrating the VTBPay payment system with the PHPShop module.
 * It handles payment processing, API requests, and logging for the VTBPay integration.
 *
 * @package VtbPay
 */
include_once($GLOBALS['SysValue']['class']['VtbApi']);
include_once($GLOBALS['SysValue']['class']['VtbPayLogger']);


/**
 * VTBPay Payment Hook
 *
 * This function is a hook for processing payments through the VTBPay payment system.
 *
 * @param object $obj The PHPShop order object for the current order.
 * @param array $value The array containing order-related values.
 * @param string $rout The routing information for the current order.
 *
 * @return void This function doesn't return a value directly, but it modifies the $obj parameter with payment information.
 *
 * @throws \Exception If there are errors during payment processing or API communication.
 */
function send_to_order_mod_vtbpay_hook($obj, $value, $rout) 
{
    // Initialize VTBPay logger
    $logger = new VtbPayLogger(dirname(__DIR__) . '/log/vtbpay.log');
    
    // Initialize PHPShop ORM and get settings
    $PHPShopOrm = new PHPShopOrm($GLOBALS['SysValue']['base']['vtbpay']['vtbpay_system']);
    $paymetSettings = $PHPShopOrm->select();
    
    // Check if the payment method matches VTBPay and the order routing is 'END'
    if ($rout == 'END' && $obj->PHPShopPayment->objRow['name'] == $paymetSettings['title']) {

        try {
            // Check if email is set in the POST data
            if (!isset($_POST['mail']) || empty($mail = $_POST['mail'])) {
                throw new \Exception('Error: Email not set.', 1);
            }
            
            // Check if the total amount is set in the order object
            if (!isset($obj->total) || empty($total = $obj->total)) {
                throw new \Exception('Error: Total not set.', 1);
            }
          
            // Initialize VTB API
            $vtbApi = new VtbApi(
                $paymetSettings['client_id'],
                $paymetSettings['client_secret'],
                $paymetSettings['test_mode'],
                $paymetSettings['merchant_authorization']
            );
            
            // Build the return URL
            $returnUrl = 'http://' . $_SERVER['HTTP_HOST'] . '/phpshop/modules/vtbpay/payment/result.php';
            
            // Get the payment link from VTB API
            $response = $vtbApi->getOrderLink(
                $value['ouid'], 
                $mail, 
                time(), 
                $total, 
                $returnUrl
            );
            
            // Log the request and response data for debugging if logging is enabled
            if($paymetSettings['logging'] === '1') {
                $logger->log(
                    basename(__FILE__) . ' > ' . __FUNCTION__ . ' > getOrderLink', 
                    VtbPayLogger::LOG_LEVEL_DEBUG, [
                    'arguments' => [
                        'ouid' => $value['ouid'], 
                        'email' => $mail, 
                        'time' => time(), 
                        'total' => $total, 
                        'return_url' => $returnUrl
                    ],
                    'response' => $response
                ]);
            }
            
            // Check if the payment URL is present and not empty in the response.
            if (
                !isset($response['object']['payUrl']) || 
                empty($payUrl = $response['object']['payUrl'])
            ) {
                throw new \Exception('Error: Failed to get payment URL.', 1);
            }
            
            // Set payment information and build payment form
            if (isset($paymetSettings['payment_info']) && !empty($paymentInfo = $paymetSettings['payment_info'])) {
                $obj->set('payment_info', $paymentInfo);
            }
            
            $obj->set('payment_forma', PHPShopText::button($paymetSettings['btn_text'], "window.location.replace('{$payUrl}')", 'btn btn-primary btn-pill'));
            $form = ParseTemplateReturn($GLOBALS['SysValue']['templates']['vtbpay']['vtbpay_payment_form'], true);

            // Clear the shopping cart
            unset($_SESSION['cart']);
            
        } catch (\Exception $e) {
            // Log errors and set error message
            $logger->log(
                basename(__FILE__) . ' > ' . __FUNCTION__ . ' > ' . $e->getMessage(), 
                VtbPayLogger::LOG_LEVEL_ERROR
            );
            
            $obj->set('mesageText', '<span style="color:red;">' . $e->getMessage() . '</span>');
            $form = ParseTemplateReturn($GLOBALS['SysValue']['templates']['order_forma_mesage']);
        }
        
        // Set order message with payment form
        $obj->set('orderMesage', $form);
    }
}

// Add the payment hook handler
$addHandler = [
    'send_to_order' => 'send_to_order_mod_vtbpay_hook'
];