<?php
/**
 * Payment Handler for VTB Payment System Notification
 *
 * This script handles payment notifications from the VTB payment system.
 * It verifies and processes payment updates for orders.
 *
 * @package VtbPay
 */
 
// Start the session
session_start();

// Include necessary classes and files
$_classPath = '../../../';
include($_classPath . 'class/obj.class.php');
include_once($_classPath . 'class/mail.class.php');

// Load required PHPShop classes
$loadedClasses = [
    'base', 'lang', 'order', 'file', 'xml', 'orm',
    'payment', 'modules', 'system', 'security',
    'parser', 'string'
];
foreach ($loadedClasses as $class) {
    PHPShopObj::loadClass($class);
}

// Initialize PHPShopBase, PHPShopSystem, and PHPShopModules
$PHPShopBase = new PHPShopBase($_classPath . 'inc/config.ini');
$PHPShopSystem = new PHPShopSystem();
$PHPShopModules = new PHPShopModules($_classPath . 'modules/');

// Include VTB API and Logger classes
include_once("{$_SERVER['DOCUMENT_ROOT']}/{$GLOBALS['SysValue']['class']['VtbApi']}");
include_once("{$_SERVER['DOCUMENT_ROOT']}/{$GLOBALS['SysValue']['class']['VtbPayLogger']}");
$PHPShopModules->checkInstall('vtbpay');

/**
 * Payment class for handling VTB payment system notifications.
 */
class Payment extends PHPShopPaymentResult {

    /**
     * Constructor for the Payment class.
     */
    function __construct() 
    {
        $this->option();
        parent::__construct();
    }
    

    /**
     * Configure the payment module options.
     *
     * This method retrieves the payment settings from the database and configures
     * the payment module accordingly. It sets the payment name and logging status.
     *
     * @throws Exception If a database error occurs during option retrieval.
     *
     * @return void
     */
    function option() 
    {
        // An instance of PHPShopOrm to interact with the database.
        $PHPShopOrm = new PHPShopOrm($GLOBALS['SysValue']['base']['vtbpay']['vtbpay_system']);
        // The payment settings retrieved from the database.
        $paymetSettings = $PHPShopOrm->select();
        $this->option = $paymetSettings;
        
        $this->payment_name = $this->option['title'];
        $this->log = true;
    }
    

    /**
     * Update order information based on payment status from the payment provider.
     *
     * This method is responsible for processing payment status updates received from
     * the payment provider. It retrieves the payment status, logs the request if
     * logging is enabled, checks if the payment is successfully paid, updates the
     * order status, logs the payment, and redirects the user to the order details page.
     *
     * @throws \Exception If there's an issue with retrieving payment status, order information,
     *                   or if the payment is not successfully paid.
     *
     * @return void
     */
    function updateorder() 
    {
        $logger = new VtbPayLogger(dirname(__DIR__) . '/log/vtbpay.log');
        
        try {
            // Check if the order ID is present in the request
            if (!isset($_GET['orderId']) || empty($uid = $_GET['orderId'])) {
                throw new \Exception('Error: No order ID found.', 1);
            }
            
            $vtbApi = $this->getVtbApi();

            // Get payment status from the payment provider
            $response = $vtbApi->getOrderInfo($uid);
            
            // Log the getOrderInfo request if logging setting is enabled
            if($this->option['logging'] === '1') {
                $logger->log(
                    basename(__FILE__) . ' > ' . __FUNCTION__ . ' >  getOrderInfo', 
                    VtbPayLogger::LOG_LEVEL_DEBUG, [
                    'arguments' => [
                        'uid' => $uid
                    ],
                    'response' => $response
                ]);
            }

            // Check if the payment is successfully paid
            if (
                !isset($response['object']['status']['value']) || 
                $response['object']['status']['value'] !== 'PAID'
            ) {
                throw new \Exception('Error: Payment not paid.', 1);
            }
              
            $PHPShopOrm = new PHPShopOrm($GLOBALS['SysValue']['base']['orders']);
            $PHPShopOrm->debug = false;
            
            // Retrieve order information from the database
            $row = $PHPShopOrm->getOne(['id', 'uid'], ['uid' => "='{$uid}'"]);
            
            // Check if the order is found
            if (empty($row['id'])) {
                throw new \Exception('Error: Order not found.', 1);
            }
            
            // Log the payment information
            $PHPShopOrm = new PHPShopOrm($GLOBALS['SysValue']['base']['payment']);
            $PHPShopOrm->insert([
                'uid_new' => str_replace('-', '', $row['uid']), 
                'name_new' => $this->payment_name,
                'sum_new' => $response['object']['amount']['value'], 
                'datas_new' => time()
            ]);

            // Update the order status as paid
            $this->setOrderPaid($row['uid']);
            
            // Redirect the user back to the order details page after processing
            header("Location: /users/order.html?order_info={$row['uid']}#Order");
            
        } catch (\Exception $e) {
            // Log the exception and display an error message
            $logger->log(
                basename(__FILE__) . ' > ' . __FUNCTION__ . ' >  ' . $e->getMessage(), 
                VtbPayLogger::LOG_LEVEL_ERROR
            );
            die($e->getMessage() . ' <a href="/">Home</a>');
        }
    }
    
    
    /**
     * Create a new VtbApi instance with the given payment method configurations.
     *
     * @return VtbApi The new VtbApi instance.
     *
     * @throws Exception If unable to create the VtbApi instance.
     */
    protected function getVtbApi(): VtbApi 
    {
        return new VtbApi(
            $this->option['client_id'],
            $this->option['client_secret'],
            $this->option['test_mode'],
            $this->option['merchant_authorization']
        );
    }
}

new Payment();

?>